# Cloud Forensics Utils

This repository contains some tools to be used by forensics teams to collect
evidence from cloud platforms (currently, only Google Cloud Platform is
supported)

## Quick install

```
pip install libcloudforensics
```